==> rill-0.0.481.tgz: package/client/util/parse.js <==
/** Rill v0.0.481 https://www.npmjs.com/package/rill License: MIT*/
var dateReg, fail, httpReg, parseDates, parsers, urllite;

urllite = require("urllite");

parseDates = require("./util/parseDates");

fail = require("./util/fail");

httpReg = /^https?:\/\//i;

dateReg = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*))(?:Z|(\+|-)([\d|:]*))?$/;

parsers = module.exports = {

  /*
  	 * When used as a transform for JSON.parse date strings will be turned into date objects.
  	#
  	 * @param {String} key
  	 * @param {String} val
   */
  date: function(key, val) {
    if ("string" === typeof val && dateReg.test(val)) {
      return new Date(val);
    } else {
      return val;
    }
  },

  /*
  	 * Extract a parsed url from a request object.
  	#
  	 * @param {Request} req
   */
  url: function(req, basePath) {
    var location, result, url;
    fail(req.url, "Could not parse an empty url.");
    location = window.location;
    url = urllite(httpReg.test(req.url) ? req.url : location.protocol + "//" + location.host + req.url);
    return result = {
      protocol: url.protocol.slice(0, -1),
      host: url.host,
      hostname: url.hostname,
      port: url.port,
      path: url.pathname.replace(basePath, ""),
      querystring: url.search.slice(1),
      hash: url.hash.slice(1),
      origin: url.origin,
      subdomains: url.host.split('.').reverse().slice(2),
      query: (function() {
        try {
          return JSON.parse(result.querystring, parsers.date);
        } catch (_error) {}
      })()
    };
  }
};

==> rill-0.0.499.tgz: package/client/util/parse.js <==
/** Rill v0.0.499 https://www.npmjs.com/package/rill License: MIT*/
var dateReg, expect, httpReg, parseDates, parsers, urllite;

urllite = require("urllite");

parseDates = require("./util/parseDates");

expect = require("./util/expect");

httpReg = /^https?:\/\//i;

dateReg = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*))(?:Z|(\+|-)([\d|:]*))?$/;

parsers = module.exports = {

  /*
  	 * When used as a transform for JSON.parse date strings will be turned into date objects.
  	#
  	 * @param {String} key
  	 * @param {String} val
   */
  date: function(key, val) {
    if ("string" === typeof val && dateReg.test(val)) {
      return new Date(val);
    } else {
      return val;
    }
  },

  /*
  	 * Extract a parsed url from a request object.
  	#
  	 * @param {Request} req
   */
  url: function(req, basePath) {
    var location, result, url;
    expect(req.url, "Could not parse an empty url.");
    location = window.location;
    url = urllite(httpReg.test(req.url) ? req.url : location.protocol + "//" + location.host + req.url);
    return result = {
      protocol: url.protocol.slice(0, -1),
      host: url.host,
      hostname: url.hostname,
      port: url.port,
      path: url.pathname.replace(basePath, ""),
      querystring: url.search.slice(1),
      hash: url.hash.slice(1),
      origin: url.origin,
      subdomains: url.host.split('.').reverse().slice(2),
      query: (function() {
        try {
          return JSON.parse(result.querystring, parsers.date);
        } catch (_error) {}
      })()
    };
  }
};
